@@ -21,85 +21,114 @@ dimnames(pres_mat) = list(sites = paste0("s", 1:3), species = letters[1:3])
 sparse_mat = as(pres_mat, "sparseMatrix")
 
 # Tests ------------------------------------------------------------------------
-test_that("'rarity_dimensions()' outputs good objects", {
-  rar_dim = rarity_dimensions(pres_mat, given_traits)
+test_that("'uniqueness_dimensions()' outputs good objects", {
+  ui_dim = uniqueness_dimensions(pres_mat, given_traits)
 
-  ## General type check
-  expect_type(rar_dim, "list")
-  expect_named(rar_dim, c("Ui", "Di"))
+  expect_s3_class(ui_dim, "data.frame")
+  expect_named(ui_dim, c("species", paste0("Ui_", trait_names), "Ui_all"))
+  expect_equal(dim(ui_dim), c(3, 5))
+})
 
-  ## On Ui element
-  expect_s3_class(rar_dim$Ui, "data.frame")
-  expect_named(rar_dim$Ui, c("species", paste0("Ui_", trait_names), "Ui_all"))
-  expect_equal(dim(rar_dim$Ui), c(3, 5))
+test_that("'distinctiveness_dimensions()' outputs good objects", {
+  di_dim = distinctiveness_dimensions(pres_mat, given_traits)
+
+  # General check
+  expect_type(di_dim, "list")
+  expect_named(di_dim, c(paste0("Di_", trait_names), "Di_all"))
 
-  ## On Di element
-  expect_type(rar_dim$Di, "list")
-  expect_named(rar_dim$Di, c(paste0("Di_", trait_names), "Di_all"))
   # Check that all elements are matrices
-  expect_true(rar_dim$Di %>%
+  expect_true(di_dim %>%
                 vapply(class, c("char")) %>%
                 `==`("matrix") %>%
                 all())
+
   # Check that all elements have good dimension
-  expect_true(rar_dim$Di %>%
+  expect_true(di_dim %>%
                 lapply(dim) %>%  # Get dimensions of each element
                 # Is it the same as input matrix?
                 lapply(function(x) all.equal(x, dim(pres_mat))) %>%
                 as.logical() %>%
                 all())  # Is it the case for all elements?
-  # Check that all elements are well named
-  expect_true(rar_dim$Di %>%
+
+  ## Check that all elements are well named
+  # Column Names
+  expect_true(di_dim %>%
                 lapply(colnames) %>%
                 lapply(function(x) all.equal(x, colnames(pres_mat))) %>%
                 as.logical() %>%
                 all())
-  expect_true(rar_dim$Di %>%
+  # Row Names
+  expect_true(di_dim %>%
                 lapply(row.names) %>%
                 lapply(function(x) all.equal(x, row.names(pres_mat))) %>%
                 as.logical() %>%
                 all())
 })
 
-test_that("'rarity_dimensions()' works with sparse matrices", {
-  expect_silent(rarity_dimensions(sparse_mat, given_traits))
+test_that("'uniqueness_dimensions()' works with sparse matrices", {
+  expect_silent(uniqueness_dimensions(sparse_mat, given_traits))
 
-  sparse_rar_dim = rarity_dimensions(sparse_mat, given_traits)
+  sparse_ui_dim = uniqueness_dimensions(sparse_mat, given_traits)
 
-  ## General type check
-  expect_type(sparse_rar_dim, "list")
-  expect_named(sparse_rar_dim, c("Ui", "Di"))
-
-  ## On Ui element
-  expect_s3_class(sparse_rar_dim$Ui, "data.frame")
-  expect_named(sparse_rar_dim$Ui, c("species", paste0("Ui_", trait_names),
+  expect_s3_class(sparse_ui_dim, "data.frame")
+  expect_named(sparse_ui_dim, c("species", paste0("Ui_", trait_names),
                                     "Ui_all"))
-  expect_equal(dim(sparse_rar_dim$Ui), c(3, 5))
+  expect_equal(dim(sparse_ui_dim), c(3, 5))
+})
+
+test_that("'distinctiveness_dimensions()' works with sparse matrices", {
+  sparse_di_dim = distinctiveness_dimensions(sparse_mat, given_traits)
+
+  # General checks
+  expect_type(sparse_di_dim, "list")
+  expect_named(sparse_di_dim, c(paste0("Di_", trait_names), "Di_all"))
 
-  ## On Di element
-  expect_type(sparse_rar_dim$Di, "list")
-  expect_named(sparse_rar_dim$Di, c(paste0("Di_", trait_names), "Di_all"))
   # Check that all elements are matrices
-  expect_true(sparse_rar_dim$Di %>%
+  expect_true(sparse_di_dim %>%
                 vapply(class, c("char")) %>%
                 `==`("dgeMatrix") %>%
                 all())
+
   # Check that all elements have good dimension
-  expect_true(sparse_rar_dim$Di %>%
+  expect_true(sparse_di_dim %>%
                 lapply(dim) %>%  # Get dimensions of each element
                 # Is it the same as input matrix?
                 lapply(function(x) all.equal(x, dim(pres_mat))) %>%
                 as.logical() %>%
                 all())  # Is it the case for all elements?
+
   # Check that all elements are well named
-  expect_true(sparse_rar_dim$Di %>%
+  expect_true(sparse_di_dim %>%
                 lapply(colnames) %>%
                 lapply(function(x) all.equal(x, colnames(pres_mat))) %>%
                 as.logical() %>%
                 all())
-  expect_true(sparse_rar_dim$Di %>%
+  expect_true(sparse_di_dim %>%
                 lapply(row.names) %>%
                 lapply(function(x) all.equal(x, row.names(pres_mat))) %>%
                 as.logical() %>%
                 all())
 })
+
+test_that("'*_dimensions()' functions outputs the right computations", {
+  simple_mat = matrix(rep(1, 4), ncol = 2)
+
+  simple_trait = data.frame(tr1 = c(0, 1))
+  rownames(simple_trait) = c("a", "b")
+
+  dimnames(simple_mat) = list(sites = c("s1", "s2"), species = c("a", "b"))
+
+  simple_ui_dim = uniqueness_dimensions(simple_mat, simple_trait)
+  simple_di_dim = distinctiveness_dimensions(simple_mat, simple_trait)
+
+  expected_ui = data.frame(species = c("a", "b"),
+                           Ui_tr1  = c(1, 1),
+                           Ui_all  = c(1, 1))
+
+  expected_single_di = matrix(1, ncol = 2, nrow = 2)
+  dimnames(expected_single_di) = dimnames(simple_mat)
+  expected_di = list(Di_tr1 = expected_single_di, Di_all = expected_single_di)
+
+  expect_identical(simple_ui_dim, expected_ui)
+  expect_identical(simple_di_dim, expected_di)
+})
